[−][src]Crate sm_ext
This interface is extremely unstable, everything just lives in a soup at the top level for now.
Macros
| c_str | Produce a |
| register_natives | |
| virtual_call | Helper for virtual function invocation that works with the |
| virtual_call_varargs | Helper for varargs-using virtual function invocation that works with the |
Structs
| DummyNativeError | Dummy error used for |
| GameFrameHookId | |
| HandleId | |
| HandleSecurity | This pair of tokens is used for identification. |
| HandleType | |
| HandleTypeId | |
| IChangeableForward | |
| IExtension | |
| IExtensionInterfaceAdapter | |
| IForward | |
| IForwardManager | |
| IHandleSys | |
| IHandleTypeDispatchAdapter | |
| IPluginContext | |
| IPluginFunction | |
| IShareSys | |
| ISourceMod | |
| IdentityToken | |
| IdentityType | |
| NativeInfo | Struct to contain name/fnptr pairs for native registration. |
| SMInterface | |
| cell_t | Wrapper type that represents a value from SourcePawn. |
Enums
| CreateForwardError | |
| ExecType | Defines how a forward iterates through plugin functions. |
| FeatureStatus | |
| FeatureType | |
| GetFunctionError | |
| HandleError | Lists the possible handle error codes. |
| IsRunningError | |
| ParamType | Describes the various ways to pass parameters to plugins. |
| PathType | Describes various ways of formatting a base path. |
| RequestInterfaceError | |
| SPError | Error codes for SourcePawn routines. |
Traits
| CallableParam | |
| ExecutableApi | |
| ICallableApi | |
| IExtensionInterface | |
| IExtensionMetadata | |
| NativeResult | The return type for native callbacks. |
| RequestableInterface | |
| SMInterfaceApi | |
| TryFromPlugin | Trait to support conversions to/from |
| TryIntoPlugin | Trait to support conversions to/from |
Functions
| safe_native_invoke | Wrapper to invoke a native callback and translate a |
Type Definitions
Attribute Macros
| forwards | |
| native | Declares a function as a native callback and generates internal support code. |
| vtable | |
| vtable_override |
Derive Macros
| ICallableApi | |
| SMExtension | Creates the entry point for SourceMod to recognise this library as an extension and set the required metadata. |
| SMInterfaceApi |