macro_rules! virtual_call {
($name:ident, $this:expr, $($param:expr),* $(,)?) => { ... };
($name:ident, $this:expr) => { ... };
}Expand description
Helper for virtual function invocation that works with the #[vtable] attribute to support
virtual calls on Windows without compiler support for the thiscall calling convention.