macro_rules! virtual_call_varargs {
($name:ident, $this:expr, $($param:expr),* $(,)?) => { ... };
($name:ident, $this:expr) => { ... };
}Expand description
Helper for varargs-using virtual function invocation that works with the #[vtable] attribute to
support virtual calls on Windows without compiler support for the thiscall calling convention.