[−][src]Struct sm_ext::ISourceMod
Methods
impl ISourceMod[src]
pub fn log_message(&self, myself: &IExtension, msg: String)[src]
pub fn log_error(&self, myself: &IExtension, msg: String)[src]
pub fn add_game_frame_hook(&self, hook: GameFrameHookFunc) -> GameFrameHookId[src]
Add a function that will be called every game frame until the GameFrameHookId return value
is dropped. This is a fairly low-level building block as the callback must be extern "C".
pub fn add_frame_action<F>(&self, func: F) where
F: FnMut() + 'static, [src]
F: FnMut() + 'static,
Add a function that will be called on the next game frame. This has a runtime cost as this API
is thread-safe on the SM side, but it supports a Rust closure so is more flexible than ISourceMod::add_game_frame_hook.