[−][src]Macro sm_ext::virtual_call
Helper for virtual function invocation that works with the #[vtable] attribute to support
virtual calls on Windows without compiler support for the thiscall calling convention.
Helper for virtual function invocation that works with the #[vtable] attribute to support
virtual calls on Windows without compiler support for the thiscall calling convention.